fn borrow_words<C: Columnar>(words: &[u64]) -> BorrowedOf<'_, C>Expand description
Reconstructs the borrowed columnar view from serialized words, the same
zero-copy decode Column::borrow performs on its Align variant.
fn borrow_words<C: Columnar>(words: &[u64]) -> BorrowedOf<'_, C>Reconstructs the borrowed columnar view from serialized words, the same
zero-copy decode Column::borrow performs on its Align variant.