fn rr<'b, 'a: 'b, C: Columnar>(item: Ref<'a, C>) -> Ref<'b, C>Expand description
Narrow a columnar ref to a shorter lifetime, so refs from different borrows, such as a probe column and a chunk’s own columns, can be compared (the refs are lifetime-invariant).